require "narray"
require "numru/ganalysis_ext"

class NArray
  def cum_sum(dim)
    case self.typecode
    when DFLOAT
      NumRu::NArrayExt.cum_sum_dfloat(self,dim)
    else
      raise "Sorry, this narray type #{self.typecode} is not supported."
    end
  end
end
